# LanguageEnum

* `et` - Eesti * `ru` - Русский * `en` - English * `us` - English (US) * `lv` - Latviski * `fi` - Suomi * `nb` - Norsk * `pl` - Polski

## Enum

* `ET` (value: `'et'`)

* `RU` (value: `'ru'`)

* `EN` (value: `'en'`)

* `US` (value: `'us'`)

* `LV` (value: `'lv'`)

* `FI` (value: `'fi'`)

* `NB` (value: `'nb'`)

* `PL` (value: `'pl'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


